/*
 * MikroSDK - MikroE Software Development Kit
 * Copyright© 2020 MikroElektronika d.o.o.
 * 
 * Permission is hereby granted, free of charge, to any person 
 * obtaining a copy of this software and associated documentation 
 * files (the "Software"), to deal in the Software without restriction, 
 * including without limitation the rights to use, copy, modify, merge, 
 * publish, distribute, sublicense, and/or sell copies of the Software, 
 * and to permit persons to whom the Software is furnished to do so, 
 * subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be 
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE 
 * OR OTHER DEALINGS IN THE SOFTWARE. 
 */

/*!
 * \file
 *
 * \brief This file contains API for Single Cell Click driver.
 *
 * \addtogroup singlecell Single Cell Click Driver
 * @{
 */
// ----------------------------------------------------------------------------

#ifndef SINGLECELL_H
#define SINGLECELL_H

#include "drv_digital_out.h"

// -------------------------------------------------------------- PUBLIC MACROS 
/**
 * \defgroup macros Macros
 * \{
 */

/**
 * \defgroup map_mikrobus MikroBUS
 * \{
 */
#define SINGLECELL_MAP_MIKROBUS( cfg, mikrobus ) \
   cfg.en= MIKROBUS( mikrobus, MIKROBUS_CS );
  
/** \} */

/**
 * \defgroup error_code Error Code
 * \{
 */
#define SINGLECELL_RETVAL  uint8_t

#define SINGLECELL_OK           0x00
#define SINGLECELL_INIT_ERROR   0xFF
/** \} */

/**
 * \defgroup en_mode Enable or disble mode
 * \{
 */
#define SINGLECELL_DISABLE      0x00
#define SINGLECELL_ENABLE       0x01
/** \} */

/** \} */ // End group macro 
// --------------------------------------------------------------- PUBLIC TYPES
/**
 * \defgroup type Types
 * \{
 */
 
/**
 * @brief Click ctx object definition.
 */
typedef struct
{
    // Output pins 

    digital_out_t en;

} singlecell_t;

/**
 * @brief Click configuration structure definition.
 */
typedef struct
{
    // Additional gpio pins 

    pin_name_t en;

} singlecell_cfg_t;

/** \} */ // End types group
// ------------------------------------------------------------------ CONSTANTS
/**
 * \defgroup constants Constants
 * \{
 */
 
 

/** \} */ // End constants group
// ------------------------------------------------------------------ VARIABLES
/**
 * \defgroup variable Variable
 * \{
 */


/** \} */ // End variable group
// ----------------------------------------------- PUBLIC FUNCTION DECLARATIONS

/**
 * \defgroup public_function Public function
 * \{
 */
 
#ifdef __cplusplus
extern "C"{
#endif

/**
 * @brief Config Object Initialization function.
 *
 * @param cfg  Click configuration structure.
 *
 * @description This function initializes click configuration structure to init state.
 * @note All used pins will be set to unconnected state.
 */
void singlecell_cfg_setup ( singlecell_cfg_t *cfg );

/**
 * @brief Initialization function.
 * @param singlecell Click object.
 * @param cfg Click configuration structure.
 * 
 * @description This function initializes all necessary pins and peripherals used for this click.
 */
SINGLECELL_RETVAL singlecell_init ( singlecell_t *ctx, singlecell_cfg_t *cfg );

/**
 * @brief Click Default Configuration function.
 *
 * @param ctx  Click object.
 *
 * @description This function executes default configuration for Single Cell click.
 * @note Disable en pin.
 */
void singlecell_default_cfg ( singlecell_t *ctx );

/**
 * @brief Set power mode function.
 *
 * @param ctx  Click object.
 * @param en_mode  Enable or disable mode.
 *
 * @description This function enabled or disabled the regulator output
 * by sets to '1' or '0' state of the EN pin for Single Cell click.
 */
void singlecell_set_power_mode ( singlecell_t *ctx, uint8_t en_mode );

#ifdef __cplusplus
}
#endif
#endif  // _SINGLECELL_H_

/** \} */ // End public_function group
/// \}    // End click Driver group  
/*! @} */
// ------------------------------------------------------------------------- END
